==> digikam-3.0.0-beta1.tar.bz2: digikam-3.0.0-beta1/extra/kipi-plugins/picasawebexport/kipiplugin_picasawebexport.desktop.cmake <==
[Desktop Entry]
Name=Picasaweb Exporter
Name[ast]=Esportador Picasaweb
Name[bg]=Изнасяне към Picasaweb
Name[bs]=Picasaweb izvoznik
Name[ca]=Exportador a Picasaweb
Name[ca@valencia]=Picasaweb Exporter
Name[cs]=Picasaweb Exportér
Name[da]=Picasaweb-eksportør
Name[de]=Picasaweb-Export
Name[el]=Εξαγωγέας Picasaweb
Name[en_GB]=Picasaweb Exporter
Name[es]=Exportar a Picasaweb
Name[et]=Picasawebi eksport
Name[eu]=Picasaweb esportatzailea
Name[fr]=Picasaweb Exporter
Name[ga]=Easpórtálaí Picasaweb
Name[gl]=Exportador a Picasaweb
Name[he]=יצוא ל-Picasaweb
Name[hne]=पिकासावेब एक्सपोर्टर
Name[hu]=Picasaweb exportáló
Name[is]=Picasaweb útflutningur
Name[it]=Esportazione a Picasa Web
Name[ja]=Picasaweb Exporter
Name[km]=កម្មវិធី​នាំចេញ Picasaweb
Name[lv]=Eksportēt uz Picasaweb
Name[nb]=Eksport til Picasaweb
Name[nds]=Picasaweb-Exporteren
Name[nl]=Picasaweb-exporter
Name[pa]=ਪਿਕਾਸਾਵੈੱਬ ਐਕਸਪੋਟਰ
Name[pl]=Eksporter Picasaweb
Name[pt]=Exportação para o Picasaweb
Name[pt_BR]=Exportar para o Picasaweb
Name[ro]=Exportator Picasaweb
Name[ru]=Экспорт в веб-альбомы Picasa
Name[sk]=Picasaweb export
Name[sl]=Izvoz v Picasaweb
Name[sq]=Picasaweb Exporter
Name[sv]=Export till Picasaweb
Name[th]=เครื่องมือส่งออกไปยังบริการ Picasaweb
Name[tr]=Picasaweb Aktarıcısı
Name[uk]=Експортер до Picasaweb
Name[x-test]=xxPicasaweb Exporterxx
Name[zh_CN]=Picasaweb 导出
Name[zh_TW]=Picasaweb 匯出程式
Comment=A tool to export images to a remote Picasa web service
Comment[ast]=Una ferramienta pa esportar imáxenes a un serviciu web remotu Picasa
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Picasa
Comment[bs]=Alat za izvoz slika na udaljeni Picasa web servis
Comment[ca]=Una eina per exportar imatges al servei web remot Picasa
Comment[ca@valencia]=Una eina per exportar imatges al servei web remot Picasa
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Picasa
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Picasa webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Picasa-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια υπηρεσία ιστού Picasa
Comment[en_GB]=A tool to export images to a remote Picasa web service
Comment[es]=Una herramienta para exportar las imágenes al servicio web remoto de Picasa
Comment[et]=Tööriist piltide eksportimiseks Picasa veebiteenusesse
Comment[eu]=Urruneko Picasa web zerbitzura irudiak esportatzeko tresna
Comment[fr]=Outil pour l'exportation vers le service en ligne Picasa
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Picasa remoto
Comment[he]=כלי ליצוא תמונות לשירות רשת Picasa מרוחק
Comment[hne]=रिमोट पिकासा वेब सेवा मं फोटू ल निर्यात करे के एक औजार
Comment[hu]=Egy eszköz képek exportálásához egy távoli Picasa webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjarlæga Picasa vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto Picasa
Comment[ja]=画像を Picasa ウェブサービスにエクスポートするツール
Comment[km]=ឧបករណ៍​ត្រូវ​នាំចេញ​រូបភាព​ទៅ​សេវា​បណ្ដាញ Picasa ពី​ចម្ងាយ
Comment[lv]=Rīks attēlu eksportēšanai uz Picasa tīmekļa servisu
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Picasa-nettjeneste
Comment[nds]=En Warktüüch, mit dat sik Biller na en feern Picasa-Nettdeenst exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Picasa-webservice te exporteren
Comment[pa]=ਚਿੱਤਰਾਂ ਨੂੰ ਪਿਕਾਸਾ ਵੈੱਬ ਸਰਵਿਸ ਉੱਤੇ ਭੇਜਣ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Picasa
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto do Picasa
Comment[pt_BR]=Uma ferramenta para exportar imagens para um serviço da Internet Picasaweb
Comment[ro]=O unealtă de exportat imagini pe serviciul web Picasa
Comment[ru]=Инструмент для экспорта изображений в веб-службу Picasa
Comment[sk]=Nástroj na export obrázkov do Picasa
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Picasa
Comment[sq]=Një mjet për të eksportuar imazhet në një shërbim interneti të Picasa
Comment[sv]=Ett verktyg för att exportera bilder till en Picasa fjärrwebbtjänst
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ ไปยังเว็บบริการ Picasa ทางไกล
Comment[tr]=Resimleri uzak bir Picasa web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Picasa
Comment[x-test]=xxA tool to export images to a remote Picasa web servicexx
Comment[zh_CN]=一个将图像导出到远程 Picasa 网络服务的工具
Comment[zh_TW]=匯出影像到遠端 Picasa 網頁服務的工具
Type=Service
Icon=picasa
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_picasawebexport
X-KIPI-PluginCategories=Export,Import
author=Vardhman Jain, vardhman@gmail.com

==> digikam-3.3.0-beta1.tar.bz2: digikam-3.3.0-beta1/extra/kipi-plugins/picasawebexport/kipiplugin_picasawebexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Picasaweb Exporter
Name=Picasaweb Exporter
Name[ast]=Esportador Picasaweb
Name[bg]=Изнасяне към Picasaweb
Name[bs]=Picasaweb izvoznik
Name[ca]=Exportador a Picasaweb
Name[ca@valencia]=Exportador a Picasaweb
Name[cs]=Picasaweb Exportér
Name[da]=Picasaweb-eksportør
Name[de]=Picasaweb-Export
Name[el]=Εξαγωγέας Picasaweb
Name[en_GB]=Picasaweb Exporter
Name[es]=Exportar a Picasaweb
Name[et]=Picasawebi eksport
Name[eu]=Picasaweb esportatzailea
Name[fr]=Export Picasaweb
Name[ga]=Easpórtálaí Picasaweb
Name[gl]=Exportador a Picasaweb
Name[he]=יצוא ל-Picasaweb
Name[hne]=पिकासावेब एक्सपोर्टर
Name[hu]=Picasaweb exportáló
Name[is]=Picasaweb útflutningur
Name[it]=Esportazione a Picasa Web
Name[ja]=Picasaweb Exporter
Name[km]=កម្មវិធី​នាំចេញ Picasaweb
Name[lv]=Eksportēt uz Picasaweb
Name[nb]=Eksport til Picasaweb
Name[nds]=Picasaweb-Exporteren
Name[nl]=Picasaweb-exporter
Name[pa]=ਪਿਕਾਸਾਵੈੱਬ ਐਕਸਪੋਟਰ
Name[pl]=Eksporter Picasaweb
Name[pt]=Exportação para o Picasaweb
Name[pt_BR]=Exportar para o Picasaweb
Name[ro]=Exportator Picasaweb
Name[ru]=Экспорт в веб-альбомы Picasa
Name[sk]=Picasaweb export
Name[sl]=Izvoz v Picasaweb
Name[sq]=Picasaweb Exporter
Name[sv]=Export till Picasaweb
Name[th]=เครื่องมือส่งออกไปยังบริการ Picasaweb
Name[tr]=Picasaweb Aktarıcısı
Name[uk]=Експортер до Picasaweb
Name[x-test]=xxPicasaweb Exporterxx
Name[zh_CN]=Picasaweb 导出
Name[zh_TW]=Picasaweb 匯出程式
Comment=A tool to export images to a remote Picasa web service
Comment[ast]=Una ferramienta pa esportar imáxenes a un serviciu web remotu Picasa
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Picasa
Comment[bs]=Alat za izvoz slika na udaljeni Picasa web servis
Comment[ca]=Una eina per exportar imatges al servei web remot Picasa
Comment[ca@valencia]=Una eina per exportar imatges al servei web remot Picasa
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Picasa
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Picasa webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Picasa-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια υπηρεσία ιστού Picasa
Comment[en_GB]=A tool to export images to a remote Picasa web service
Comment[es]=Una herramienta para exportar las imágenes al servicio web remoto de Picasa
Comment[et]=Tööriist piltide eksportimiseks Picasa veebiteenusesse
Comment[eu]=Urruneko Picasa web zerbitzura irudiak esportatzeko tresna
Comment[fr]=Outil pour l'exportation vers le service en ligne Picasa
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Picasa remoto
Comment[he]=כלי ליצוא תמונות לשירות רשת Picasa מרוחק
Comment[hne]=रिमोट पिकासा वेब सेवा मं फोटू ल निर्यात करे के एक औजार
Comment[hu]=Egy eszköz képek exportálásához egy távoli Picasa webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjarlæga Picasa vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto Picasa
Comment[ja]=画像を Picasa ウェブサービスにエクスポートするツール
Comment[km]=ឧបករណ៍​ត្រូវ​នាំចេញ​រូបភាព​ទៅ​សេវា​បណ្ដាញ Picasa ពី​ចម្ងាយ
Comment[lv]=Rīks attēlu eksportēšanai uz Picasa tīmekļa servisu
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Picasa-nettjeneste
Comment[nds]=En Warktüüch, mit dat sik Biller na en feern Picasa-Nettdeenst exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Picasa-webservice te exporteren
Comment[pa]=ਚਿੱਤਰਾਂ ਨੂੰ ਪਿਕਾਸਾ ਵੈੱਬ ਸਰਵਿਸ ਉੱਤੇ ਭੇਜਣ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Picasa
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto do Picasa
Comment[pt_BR]=Uma ferramenta para exportar imagens para um serviço da Internet Picasaweb
Comment[ro]=O unealtă de exportat imagini pe serviciul web Picasa
Comment[ru]=Инструмент для экспорта изображений в веб-службу Picasa
Comment[sk]=Nástroj na export obrázkov do Picasa
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Picasa
Comment[sq]=Një mjet për të eksportuar imazhet në një shërbim interneti të Picasa
Comment[sv]=Ett verktyg för att exportera bilder till en Picasa fjärrwebbtjänst
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ ไปยังเว็บบริการ Picasa ทางไกล
Comment[tr]=Resimleri uzak bir Picasa web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Picasa
Comment[x-test]=xxA tool to export images to a remote Picasa web servicexx
Comment[zh_CN]=一个将图像导出到远程 Picasa 网络服务的工具
Comment[zh_TW]=匯出影像到遠端 Picasa 網頁服務的工具
Type=Service
Icon=picasa
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_picasawebexport
X-KIPI-PluginCategories=Export,Import
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Vardhman Jain, vardhman@gmail.com
